@@ -33,35 +33,23 @@
 #
 #######################################################################
 
-# run with a simple 'nosetests' in this directory
-# (and nose installed, i.e. 'easy_install nose')
+# run with a simple 'pytest' in this directory
+# (and pytest installed, i.e. 'pip install pytest' or 'conda install pytest')
 
-from __future__ import division, print_function
 from functools import reduce
 
 import sys
-print("\nexecuting test file", __file__, file=sys.stderr)
 exec(compile(open('set_paths.py', "rb").read(), 'set_paths.py', 'exec'))
 # import vigra  # FIXME: without this line, C++ constructors don't find VigraArray
 import vigra.arraytypes as arraytypes
 import vigra.ufunc as ufunc
 import numpy, copy
 import vigranumpytest as vt
-from nose.tools import assert_equal, raises, assert_true
 
 from vigra.arraytypes import AxisTags, AxisInfo
 import platform
 IS_PYPY = platform.python_implementation() == 'PyPy'
 
-if sys.version_info[0] > 2:
-    def xrange(*args):
-        return range(*args)
-
-    def iteritems(dictionary, **kwargs):
-        return dictionary.items(**kwargs)
-else:
-    def iteritems(dictionary, **kwargs):
-        return dictionary.iteritems(**kwargs)
 
 numpyHasComplexNegateBug = numpy.version.version.startswith('1.0')
 
@@ -75,6 +63,16 @@ for n, f in vt.__dict__.items():
     if n.startswith('test'):
         allTests.add(n)
 
+# 2023/09
+# Small compatibility shims with old code that used
+#     assert_equal
+# from nosetest. Rewriting the tests to use python's assert statement
+# was decided to be too invasive.
+def assert_equal(x, y):
+    assert x == y
+
+
+
 def checkShape(shape1, shape2):
     assert_equal(shape1, shape2)
 
@@ -166,7 +164,7 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
         if channels > 1:
             assert_equal(img.order, "V" if hasChannelAxis else "F")
         else:
-            assert_true(img.order in ['V', 'F'])
+            assert img.order in ['V', 'F']
         assert_equal(img.flags.c_contiguous, False)
 
         # test axistags
@@ -175,7 +173,7 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
         assert_equal(img.withAxes('y', 'z', 'x', 'c').axistags, axistags4)
         assert_equal(img.withAxes('yzxc').axistags, axistags4)
         assert_equal(img.withAxes(axistags4).axistags, axistags4)
-        assert_true(img.withAxes(img.axistags) is img)
+        assert img.withAxes(img.axistags) is img
         array = img.noTags()
         assert_equal(type(array), numpy.ndarray)
         assert_equal(arraytypes.taggedView(array, vaxistags).axistags, vaxistags)
@@ -254,7 +252,7 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
         if channels > 1:
             assert_equal(img.order, "V" if hasChannelAxis else "F")
         else:
-            assert_true(img.order in ['V', 'F'])
+            assert img.order in ['V', 'F']
         assert_equal(img.flags.c_contiguous, False)
         assert_equal(img.axistags, vaxistags)
         img[1,2] = value
@@ -308,7 +306,7 @@ def checkArray(cls, channels, dim, hasChannelAxis=True):
         if channels > 1:
             assert_equal(img.order, "V" if hasChannelAxis else "F")
         else:
-            assert_true(img.order in ['V', 'F'])
+            assert img.order in ['V', 'F']
         assert_equal(b.axistags, img.axistags)
         assert_equal(b.flags.c_contiguous, False)
         assert (b==img).all()
@@ -455,7 +453,7 @@ def checkCompatibility(obj, compatible):
         except Exception:
             print("exception in %s with shape %s strides %s tags (%s)" % (n, obj.shape, obj.strides,
                                             repr(getattr(obj, "axistags", "none"))))
-            raise     
+            raise
 
 def testAxisTags():
     axistags = AxisTags(AxisInfo.c(description="RGB"),
@@ -1362,13 +1360,13 @@ def testZMQ():
 
 def testSlicing():
     a = arraytypes.Vector2Volume((5,4,3))
-    a.flat[...] = xrange(a.size)
+    a.flat[...] = range(a.size)
 
     tags = arraytypes.VigraArray.defaultAxistags('xyzc')
     assert_equal(tags, a.axistags)
 
     b = a[...]
-    assert_true((a==b).all())
+    assert (a==b).all()
     assert_equal(tags, b.axistags)
 
     b = a[...,0]
@@ -1409,17 +1407,17 @@ def testSlicing():
 
     b = a.subarray((4,3,2))
     assert_equal(b.shape, (4,3,2,2))
-    assert_true((a[:4,:3,:2,:]==b).all())
+    assert (a[:4,:3,:2,:]==b).all()
     assert_equal(tags, b.axistags)
 
     b = a.subarray((1,1,1),(4,3,2))
     assert_equal(b.shape, (3,2,1,2))
-    assert_true((a[1:4,1:3,1:2]==b).all())
+    assert (a[1:4,1:3,1:2]==b).all()
     assert_equal(tags, b.axistags)
 
     b = a.subarray((1,1,1,1),(4,3,2,2))
     assert_equal(b.shape, (3,2,1,1))
-    assert_true((a[1:4,1:3,1:2,1:]==b).all())
+    assert (a[1:4,1:3,1:2,1:]==b).all()
     assert_equal(tags, b.axistags)
 
 def testMethods():
@@ -1428,7 +1426,7 @@ def testMethods():
 
     a.ravel()[...] = range(a.size)
 
-    for k, i in zip(a.flat, xrange(a.size)):
+    for k, i in zip(a.flat, range(a.size)):
         assert_equal(k, i)
 
     assert (a.flatten() == range(a.size)).all()
@@ -1553,7 +1551,7 @@ def testUfuncs():
     for t in types:
         arrays[t] = arraytypes.ScalarImage((2,2), t, value=2)
         ones[t] = arraytypes.ScalarImage((1,1), t, value=1)
-    for t, a in iteritems(arrays):
+    for t, a in arrays.items():
         b = -a
         assert_equal(t, b.dtype)
         assert_equal(a.axistags, b.axistags)
